# Repository path:    $HeadURL: https://90.145.156.222/DMS-Houtribdijk/code/python-ftp-svn/source/Locations.py $
# Last committed:     $Revision: 384466 $; $Author: svcdms $; $Date: 2019-10-23 17:59:43 +0200 (wo, 23 okt 2019) $
#
# Dit script leest de status-file en maakt daar een locatie-bestand voor Delft-FEWS van
#
import os
import re
import pandas as pd
from collections import defaultdict
from datetime import datetime
from misc.ReadMetaData import ReadMetaData
from misc.Utils import Utils

settings = Utils.read_location_settings()
status_list = os.listdir(settings["status_folder"])

x_default = 157533
y_default = 515200

# create a dataframe with timenow only
date_today = datetime.now()
days = pd.date_range(date_today, date_today)
df = pd.DataFrame({'date': days})
df = df.set_index('date')

read_meta_data = ReadMetaData(settings["logboek_file"], df.index)
meta_data = read_meta_data.get_meta_data()

locations = defaultdict(list)
parents = {}
for status in status_list:
    if re.match(r"^\.", status):
        continue

    r = re.match(r"^_(\w+)_status.json$", status)
    l = r.group(1).split("_")
    sensor = l[0]
    del l[0]
    location = ""
    parent = ""
    if len(l) == 1:
        location = l[0]
    elif len(l) == 2:
        location = "_".join(l)
        parent = l[0]
    # print(location, parent, sensor)
    locations[location].append(sensor)
    parents[location] = parent

with open(settings["metadata_file"], "w") as f:
    f.write("locid,name,x,y,type,parent\n")    
    for loc in locations:
        x = x_default
        y = y_default

        if loc in list(meta_data):
            x = meta_data[loc]["X"]
            y = meta_data[loc]["Y"]
            naam = meta_data[loc]["Naam"]
            # print(naam)

            f.write("{},{},{},{},{},{}\n".format(loc, naam, x, y, "/".join(locations[loc]), parents[loc]))


with open(settings["drukoffset_file"], "w") as f:
    f.write("locid,ADV,AQD\n")
    for loc in locations:
        if loc in list(meta_data):
            try:
                adv_offset = meta_data[loc]["drukOffsetAdv"]
            except KeyError:
                adv_offset = ""
            try:
                aqd_offset = meta_data[loc]["drukOffsetAqd"]
            except KeyError:
                aqd_offset = ""

            if not (adv_offset=="" and aqd_offset==""):
                f.write(
                    "{},{},{}\n".format(
                        loc, adv_offset, aqd_offset
                    )
                )
